@@ -341,10 +341,16 @@ int cpbuilder_build(const struct pbuilderconfig *pc, const char *dscfile_) {
 		PBUILDER_ADD_PARAM("--buildresult");
 		PBUILDER_ADD_PARAM(pc->buildresult);
 	}
+	if (pc->mirror) {
+		PBUILDER_ADD_PARAM("--mirror");
+		PBUILDER_ADD_PARAM(pc->mirror);
+	}
 	if (pc->arch) {
 		PBUILDER_ADD_PARAM("--architecture");
 		PBUILDER_ADD_PARAM(pc->arch);
 	}
+	PBUILDER_ADD_PARAM("--distribution");
+	PBUILDER_ADD_PARAM(pc->distribution);
 	if (pc->extrapackages) {
 		PBUILDER_ADD_PARAM("--extrapackages");
 		PBUILDER_ADD_PARAM(pc->extrapackages);
@@ -476,6 +482,12 @@ int cpbuilder_login(const struct pbuilderconfig *pc) {
 	pbuildercommandline[1] = "login";
 	PBUILDER_ADD_PARAM("--buildplace");
 	PBUILDER_ADD_PARAM(pc->buildplace);
+	if (pc->mirror) {
+		PBUILDER_ADD_PARAM("--mirror");
+		PBUILDER_ADD_PARAM(pc->mirror);
+	}
+	PBUILDER_ADD_PARAM("--distribution");
+	PBUILDER_ADD_PARAM(pc->distribution);
 	PBUILDER_ADD_PARAM("--no-targz");
 	PBUILDER_ADD_PARAM("--internal-chrootexec");
 	PBUILDER_ADD_PARAM(buf_chroot);
@@ -528,6 +540,12 @@ int cpbuilder_execute(const struct pbuilderconfig *pc, char **av) {
 	pbuildercommandline[1] = "execute";
 	PBUILDER_ADD_PARAM("--buildplace");
 	PBUILDER_ADD_PARAM(pc->buildplace);
+	if (pc->mirror) {
+		PBUILDER_ADD_PARAM("--mirror");
+		PBUILDER_ADD_PARAM(pc->mirror);
+	}
+	PBUILDER_ADD_PARAM("--distribution");
+	PBUILDER_ADD_PARAM(pc->distribution);
 	PBUILDER_ADD_PARAM("--no-targz");
 	PBUILDER_ADD_PARAM("--internal-chrootexec");
 	PBUILDER_ADD_PARAM(buf_chroot);
@@ -625,14 +643,12 @@ int cpbuilder_update(const struct pbuilderconfig *pc) {
 	pbuildercommandline[1] = "update";
 	PBUILDER_ADD_PARAM("--buildplace");
 	PBUILDER_ADD_PARAM(pc->buildplace);
-	if (find_matching_param("--override-config")) {
-		if (pc->mirror) {
-			PBUILDER_ADD_PARAM("--mirror");
-			PBUILDER_ADD_PARAM(pc->mirror);
-		}
-		PBUILDER_ADD_PARAM("--distribution");
-		PBUILDER_ADD_PARAM(pc->distribution);
+	if (pc->mirror) {
+		PBUILDER_ADD_PARAM("--mirror");
+		PBUILDER_ADD_PARAM(pc->mirror);
 	}
+	PBUILDER_ADD_PARAM("--distribution");
+	PBUILDER_ADD_PARAM(pc->distribution);
 	if (pc->extrapackages) {
 		PBUILDER_ADD_PARAM("--extrapackages");
 		PBUILDER_ADD_PARAM(pc->extrapackages);
