@@ -416,8 +416,9 @@ int parse_parameter(int ac, char **av, const char *keyword) {
 		/* qemubuilder specific options */
 		{"arch-diskdevice", no_argument, 0, 0},
 
-		/* verbatim options with argument, synced as of pbuilder 0.228 */
+		/* verbatim options with argument, synced as of pbuilder 0.230.4 */
 		{"use-network", required_argument, 0, 'M'},
+		{"use-cgroup", required_argument, 0, 'M'},
 		{"host-arch", required_argument, 0, 'M'},
 		{"aptcache", required_argument, 0, 'M'},
 		{"debemail", required_argument, 0, 'M'},
@@ -432,13 +433,14 @@ int parse_parameter(int ac, char **av, const char *keyword) {
 		{"keyring", required_argument, 0, 'M'},
 		{"bindmounts", required_argument, 0, 'M'},
 
-		/* verbatim options without argument, synced as of pbuilder 0.228 */
+		/* verbatim options without argument, synced as of pbuilder 0.230.4 */
 		{"no-auto-cross", no_argument, 0, 'm'},
 		{"autocleanaptcache", no_argument, 0, 'm'},
 		{"removepackages", no_argument, 0, 'm'},
 		{"pkgname-logfile", no_argument, 0, 'm'},
 		{"override-config", no_argument, 0, 'm'},
 		{"source-only-changes", no_argument, 0, 'm'},
+		{"no-source-only-changes", no_argument, 0, 'm'},
 		{"preserve-buildplace", no_argument, 0, 'm'},
 		{"debdelta", no_argument, 0, 'm'},
 		{"twice", no_argument, 0, 'm'},
